@@ -1,5 +1,5 @@
 /* Clzip - LZMA lossless data compressor
-   Copyright (C) 2010-2024 Antonio Diaz Diaz.
+   Copyright (C) 2010-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ Dis_slots dis_slots;
 Prob_prices prob_prices;
 
 
-bool Mb_read_block( struct Matchfinder_base * const mb )
+bool Mb_read_block( Matchfinder_base * const mb )
   {
   if( !mb->at_stream_end && mb->stream_pos < mb->buffer_size )
     {
@@ -46,7 +46,7 @@ bool Mb_read_block( struct Matchfinder_base * const mb )
   }
 
 
-void Mb_normalize_pos( struct Matchfinder_base * const mb )
+void Mb_normalize_pos( Matchfinder_base * const mb )
   {
   if( mb->pos > mb->stream_pos )
     internal_error( "pos > stream_pos in Mb_normalize_pos." );
@@ -69,7 +69,7 @@ void Mb_normalize_pos( struct Matchfinder_base * const mb )
   }
 
 
-bool Mb_init( struct Matchfinder_base * const mb, const int before_size,
+bool Mb_init( Matchfinder_base * const mb, const int before_size,
               const int dict_size, const int after_size,
               const int dict_factor, const int num_prev_positions23,
               const int pos_array_factor, const int ifd )
@@ -123,7 +123,7 @@ bool Mb_init( struct Matchfinder_base * const mb, const int before_size,
   }
 
 
-void Mb_reset( struct Matchfinder_base * const mb )
+void Mb_reset( Matchfinder_base * const mb )
   {
   int i;
   if( mb->stream_pos > mb->pos )
@@ -147,13 +147,13 @@ void Mb_reset( struct Matchfinder_base * const mb )
   }
 
 
-void Re_flush_data( struct Range_encoder * const renc )
+void Re_flush_data( Range_encoder * const renc )
   {
   if( renc->pos > 0 )
     {
     if( renc->outfd >= 0 &&
         writeblock( renc->outfd, renc->buffer, renc->pos ) != renc->pos )
-      { show_error( "Write error", errno, false ); cleanup_and_fail( 1 ); }
+      { show_error( wr_err_msg, errno, false ); cleanup_and_fail( 1 ); }
     renc->partial_member_pos += renc->pos;
     renc->pos = 0;
     show_cprogress( 0, 0, 0, 0 );
@@ -162,7 +162,7 @@ void Re_flush_data( struct Range_encoder * const renc )
 
 
 /* End Of Stream marker => (dis == 0xFFFFFFFFU, len == min_match_len) */
-void LZeb_full_flush( struct LZ_encoder_base * const eb, const State state )
+void LZeb_full_flush( LZ_encoder_base * const eb, const State state )
   {
   const int pos_state = Mb_data_position( &eb->mb ) & pos_state_mask;
   Re_encode_bit( &eb->renc, &eb->bm_match[state][pos_state], 1 );
@@ -178,7 +178,7 @@ void LZeb_full_flush( struct LZ_encoder_base * const eb, const State state )
   }
 
 
-void LZeb_reset( struct LZ_encoder_base * const eb )
+void LZeb_reset( LZ_encoder_base * const eb )
   {
   Mb_reset( &eb->mb );
   eb->crc = 0xFFFFFFFFU;
