@@ -1,5 +1,5 @@
 /* Clzip - LZMA lossless data compressor
-   Copyright (C) 2010-2024 Antonio Diaz Diaz.
+   Copyright (C) 2010-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,13 +15,13 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-struct FLZ_encoder
+typedef struct FLZ_encoder
   {
-  struct LZ_encoder_base eb;
+  LZ_encoder_base eb;
   unsigned key4;			/* key made from latest 4 bytes */
-  };
+  } FLZ_encoder;
 
-static inline void FLZe_reset_key4( struct FLZ_encoder * const fe )
+static inline void FLZe_reset_key4( FLZ_encoder * const fe )
   {
   int i;
   fe->key4 = 0;
@@ -29,11 +29,11 @@ static inline void FLZe_reset_key4( struct FLZ_encoder * const fe )
     fe->key4 = ( fe->key4 << 4 ) ^ fe->eb.mb.buffer[i];
   }
 
-int FLZe_longest_match_len( struct FLZ_encoder * const fe, int * const distance );
+int FLZe_longest_match_len( FLZ_encoder * const fe, int * const distance );
 
-static inline void FLZe_update_and_move( struct FLZ_encoder * const fe, int n )
+static inline void FLZe_update_and_move( FLZ_encoder * const fe, int n )
   {
-  struct Matchfinder_base * const mb = &fe->eb.mb;
+  Matchfinder_base * const mb = &fe->eb.mb;
   while( --n >= 0 )
     {
     if( Mb_available_bytes( mb ) >= 4 )
@@ -46,7 +46,7 @@ static inline void FLZe_update_and_move( struct FLZ_encoder * const fe, int n )
     }
   }
 
-static inline bool FLZe_init( struct FLZ_encoder * const fe,
+static inline bool FLZe_init( FLZ_encoder * const fe,
                               const int ifd, const int outfd )
   {
   enum { before_size = 0,
@@ -61,8 +61,8 @@ static inline bool FLZe_init( struct FLZ_encoder * const fe,
                     num_prev_positions23, pos_array_factor, ifd, outfd );
   }
 
-static inline void FLZe_reset( struct FLZ_encoder * const fe )
+static inline void FLZe_reset( FLZ_encoder * const fe )
   { LZeb_reset( &fe->eb ); }
 
-bool FLZe_encode_member( struct FLZ_encoder * const fe,
+bool FLZe_encode_member( FLZ_encoder * const fe,
                          const unsigned long long member_size );
