@@ -1,5 +1,5 @@
 /* Clzip - LZMA lossless data compressor
-   Copyright (C) 2010-2024 Antonio Diaz Diaz.
+   Copyright (C) 2010-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ static inline State St_set_match( const State st )
   { return ( st < 7 ) ? 7 : 10; }
 static inline State St_set_rep( const State st )
   { return ( st < 7 ) ? 8 : 11; }
-static inline State St_set_short_rep( const State st )
+static inline State St_set_shortrep( const State st )
   { return ( st < 7 ) ? 9 : 11; }
 
 
@@ -92,16 +92,16 @@ static inline void Bm_init( Bit_model * const probability )
 static inline void Bm_array_init( Bit_model bm[], const int size )
   { int i; for( i = 0; i < size; ++i ) Bm_init( &bm[i] ); }
 
-struct Len_model
+typedef struct Len_model
   {
   Bit_model choice1;
   Bit_model choice2;
   Bit_model bm_low[pos_states][len_low_symbols];
   Bit_model bm_mid[pos_states][len_mid_symbols];
   Bit_model bm_high[len_high_symbols];
-  };
+  } Len_model;
 
-static inline void Lm_init( struct Len_model * const lm )
+static inline void Lm_init( Len_model * const lm )
   {
   Bm_init( &lm->choice1 );
   Bm_init( &lm->choice2 );
@@ -276,17 +276,14 @@ static inline bool Lt_check_consistency( const Lzip_trailer data )
   }
 
 
-struct Cl_options		/* command-line options */
+typedef struct Cl_options	/* command-line options */
   {
-  bool ignore_empty;
-  bool ignore_marking;
   bool ignore_trailing;
   bool loose_trailing;
-  };
+  } Cl_options;
 
-static inline void Cl_options_init( struct Cl_options * cl_opts )
-  { cl_opts->ignore_empty = true; cl_opts->ignore_marking = true;
-    cl_opts->ignore_trailing = true; cl_opts->loose_trailing = false; }
+static inline void Cl_options_init( Cl_options * cl_opts )
+  { cl_opts->ignore_trailing = true; cl_opts->loose_trailing = false; }
 
 
 static inline void set_retval( int * retval, const int new_val )
@@ -296,9 +293,10 @@ static const char * const bad_magic_msg = "Bad magic number (file not in lzip fo
 static const char * const bad_dict_msg = "Invalid dictionary size in member header.";
 static const char * const corrupt_mm_msg = "Corrupt header in multimember file.";
 static const char * const empty_msg = "Empty member not allowed.";
-static const char * const marking_msg = "Marking data not allowed.";
-static const char * const trailing_msg = "Trailing data not allowed.";
 static const char * const mem_msg = "Not enough memory.";
+static const char * const nonzero_msg = "Nonzero first LZMA byte.";
+static const char * const trailing_msg = "Trailing data not allowed.";
+static const char * const wr_err_msg = "Write error";
 
 /* defined in decoder.c */
 int readblock( const int fd, uint8_t * const buf, const int size );
@@ -306,14 +304,16 @@ int writeblock( const int fd, const uint8_t * const buf, const int size );
 
 /* defined in list.c */
 int list_files( const char * const filenames[], const int num_filenames,
-                const struct Cl_options * const cl_opts );
+                const Cl_options * const cl_opts );
 
 /* defined in main.c */
 struct stat;
-struct Pretty_print;
+typedef struct Matchfinder_base Matchfinder_base;
+typedef struct Pretty_print Pretty_print;
+typedef struct Range_decoder Range_decoder;
 extern int verbosity;
 void * resize_buffer( void * buf, const unsigned min_size );
-void Pp_show_msg( struct Pretty_print * const pp, const char * const msg );
+void Pp_show_msg( Pretty_print * const pp, const char * const msg );
 const char * bad_version( const unsigned version );
 const char * format_ds( const unsigned dictionary_size );
 void show_header( const unsigned dictionary_size );
@@ -324,13 +324,11 @@ void show_error( const char * const msg, const int errcode, const bool help );
 void show_file_error( const char * const filename, const char * const msg,
                       const int errcode );
 void internal_error( const char * const msg );
-struct Matchfinder_base;
 void show_cprogress( const unsigned long long cfile_size,
                      const unsigned long long partial_size,
-                     const struct Matchfinder_base * const m,
-                     struct Pretty_print * const p );
-struct Range_decoder;
+                     const Matchfinder_base * const m,
+                     Pretty_print * const p );
 void show_dprogress( const unsigned long long cfile_size,
                      const unsigned long long partial_size,
-                     const struct Range_decoder * const d,
-                     struct Pretty_print * const p );
+                     const Range_decoder * const d,
+                     Pretty_print * const p );
