@@ -1,5 +1,5 @@
 /* Clzip - LZMA lossless data compressor
-   Copyright (C) 2010-2024 Antonio Diaz Diaz.
+   Copyright (C) 2010-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 #include <ctype.h>
 #include <errno.h>
 #include <fcntl.h>
-#include <limits.h>		/* SSIZE_MAX */
+#include <limits.h>		/* CHAR_BIT, SSIZE_MAX */
 #include <signal.h>
 #include <stdbool.h>
 #include <stdint.h>		/* SIZE_MAX */
@@ -39,8 +39,10 @@
 #if defined __MSVCRT__ || defined __OS2__ || defined __DJGPP__
 #include <io.h>
 #if defined __MSVCRT__
+#include <direct.h>
 #define fchmod(x,y) 0
 #define fchown(x,y,z) 0
+#define mkdir(name,mode) _mkdir(name)
 #define strtoull strtoul
 #define SIGHUP SIGTERM
 #define S_ISSOCK(x) 0
@@ -80,7 +82,7 @@
 int verbosity = 0;
 
 static const char * const program_name = "clzip";
-static const char * const program_year = "2024";
+static const char * const program_year = "2025";
 static const char * invocation_name = "clzip";		/* default value */
 
 static const struct { const char * from; const char * to; } known_extensions[] = {
@@ -88,13 +90,13 @@ static const struct { const char * from; const char * to; } known_extensions[] =
   { ".tlz", ".tar" },
   { 0,      0      } };
 
-struct Lzma_options
+typedef struct Lzma_options
   {
   int dictionary_size;		/* 4 KiB .. 512 MiB */
   int match_len_limit;		/* 5 .. 273 */
-  };
+  } Lzma_options;
 
-enum Mode { m_compress, m_decompress, m_list, m_test };
+typedef enum Mode { m_compress, m_decompress, m_list, m_test } Mode;
 
 /* Variables used in signal handler context.
    They are not declared volatile because the handler never returns. */
@@ -105,26 +107,25 @@ static bool delete_output_on_interrupt = false;
 
 static void show_help( void )
   {
-  printf( "Clzip is a C language version of lzip, compatible with lzip 1.4 or newer. As\n"
-          "clzip is written in C, it may be easier to integrate in applications like\n"
-          "package managers, embedded devices, or systems lacking a C++ compiler.\n"
+  printf( "Clzip is a C language version of lzip intended for systems lacking a C++\n"
+          "compiler.\n"
           "\nLzip is a lossless data compressor with a user interface similar to the one\n"
-          "of gzip or bzip2. Lzip uses a simplified form of the 'Lempel-Ziv-Markov\n"
-          "chain-Algorithm' (LZMA) stream format to maximize interoperability. The\n"
-          "maximum dictionary size is 512 MiB so that any lzip file can be decompressed\n"
-          "on 32-bit machines. Lzip provides accurate and robust 3-factor integrity\n"
-          "checking. Lzip can compress about as fast as gzip (lzip -0) or compress most\n"
-          "files more than bzip2 (lzip -9). Decompression speed is intermediate between\n"
-          "gzip and bzip2. Lzip is better than gzip and bzip2 from a data recovery\n"
-          "perspective. Lzip has been designed, written, and tested with great care to\n"
-          "replace gzip and bzip2 as the standard general-purpose compressed format for\n"
-          "Unix-like systems.\n"
+          "of gzip or bzip2. Lzip uses a simplified form of LZMA (Lempel-Ziv-Markov\n"
+          "chain-Algorithm) designed to achieve complete interoperability between\n"
+          "implementations. The maximum dictionary size is 512 MiB so that any lzip\n"
+          "file can be decompressed on 32-bit machines. Lzip provides accurate and\n"
+          "robust 3-factor integrity checking. 'lzip -0' compresses about as fast as\n"
+          "gzip, while 'lzip -9' compresses most files more than bzip2. Decompression\n"
+          "speed is intermediate between gzip and bzip2. Lzip provides better data\n"
+          "recovery capabilities than gzip and bzip2. Lzip has been designed, written,\n"
+          "and tested with great care to replace gzip and bzip2 as general-purpose\n"
+          "compressed format for Unix-like systems.\n"
           "\nUsage: %s [options] [files]\n", invocation_name );
   printf( "\nOptions:\n"
           "  -h, --help                     display this help and exit\n"
           "  -V, --version                  output version information and exit\n"
           "  -a, --trailing-error           exit with error status if trailing data\n"
-          "  -b, --member-size=<bytes>      set member size limit in bytes\n"
+          "  -b, --member-size=<bytes>      set member size limit of multimember files\n"
           "  -c, --stdout                   write to standard output, keep input files\n"
           "  -d, --decompress               decompress, test compressed file integrity\n"
           "  -f, --force                    overwrite existing output files\n"
@@ -141,8 +142,6 @@ static void show_help( void )
           "  -0 .. -9                       set compression level [default 6]\n"
           "      --fast                     alias for -0\n"
           "      --best                     alias for -9\n"
-          "      --empty-error              exit with error status if empty member in file\n"
-          "      --marking-error            exit with error status if 1st LZMA byte not 0\n"
           "      --loose-trailing           allow trailing data seeming corrupt header\n"
           "\nIf no file names are given, or if a file is '-', clzip compresses or\n"
           "decompresses from standard input to standard output.\n"
@@ -199,7 +198,7 @@ struct Pretty_print
   bool first_post;
   };
 
-static void Pp_init( struct Pretty_print * const pp,
+static void Pp_init( Pretty_print * const pp,
                      const char * const filenames[], const int num_filenames )
   {
   pp->name = 0;
@@ -220,8 +219,10 @@ static void Pp_init( struct Pretty_print * const pp,
   if( pp->longest_name == 0 ) pp->longest_name = stdin_name_len;
   }
 
-static void Pp_set_name( struct Pretty_print * const pp,
-                         const char * const filename )
+void Pp_free( Pretty_print * const pp )
+  { if( pp->padded_name ) { free( pp->padded_name ); pp->padded_name = 0; } }
+
+static void Pp_set_name( Pretty_print * const pp, const char * const filename )
   {
   unsigned name_len, padded_name_len, i = 0;
 
@@ -239,10 +240,10 @@ static void Pp_set_name( struct Pretty_print * const pp,
   pp->first_post = true;
   }
 
-static void Pp_reset( struct Pretty_print * const pp )
+static void Pp_reset( Pretty_print * const pp )
   { if( pp->name && pp->name[0] ) pp->first_post = true; }
 
-void Pp_show_msg( struct Pretty_print * const pp, const char * const msg )
+void Pp_show_msg( Pretty_print * const pp, const char * const msg )
   {
   if( verbosity < 0 ) return;
   if( pp->first_post )
@@ -272,7 +273,7 @@ const char * format_ds( const unsigned dictionary_size )
   const char * p = "";
   const char * np = "  ";
   unsigned num = dictionary_size;
-  bool exact = ( num % factor == 0 );
+  bool exact = num % factor == 0;
 
   int i; for( i = 0; i < n && ( num > 9999 || ( exact && num >= factor ) ); ++i )
     { num /= factor; if( num % factor != 0 ) exact = false;
@@ -300,7 +301,7 @@ static const char * format_num3( unsigned long long num )
   char * const buf = buffer[current++]; current %= buffers;
   char * p = buf + bufsize - 1;		/* fill the buffer backwards */
   *p = 0;	/* terminator */
-  if( num > 1024 )
+  if( num > 9999 )
     {
     char prefix = 0;			/* try binary first, then si */
     for( i = 0; i < n && num != 0 && num % 1024 == 0; ++i )
@@ -346,7 +347,7 @@ static unsigned long long getnum( const char * const arg,
 
   if( !errno && tail[0] )
     {
-    const unsigned factor = ( tail[1] == 'i' ) ? 1024 : 1000;
+    const unsigned factor = (tail[1] == 'i') ? 1024 : 1000;
     int exponent = 0;				/* 0 = bad multiplier */
     int i;
     switch( tail[0] )
@@ -396,7 +397,7 @@ static int get_dict_size( const char * const arg, const char * const option_name
   }
 
 
-static void set_mode( enum Mode * const program_modep, const enum Mode new_mode )
+static void set_mode( Mode * const program_modep, const Mode new_mode )
   {
   if( *program_modep != m_compress && *program_modep != new_mode )
     {
@@ -473,9 +474,9 @@ int open_instream( const char * const name, struct stat * const in_statsp,
     {
     const int i = fstat( infd, in_statsp );
     const mode_t mode = in_statsp->st_mode;
-    const bool can_read = ( i == 0 && !reg_only &&
-                            ( S_ISBLK( mode ) || S_ISCHR( mode ) ||
-                              S_ISFIFO( mode ) || S_ISSOCK( mode ) ) );
+    const bool can_read = i == 0 && !reg_only &&
+                          ( S_ISBLK( mode ) || S_ISCHR( mode ) ||
+                            S_ISFIFO( mode ) || S_ISSOCK( mode ) );
     if( i != 0 || ( !S_ISREG( mode ) && ( !can_read || one_to_one ) ) )
       {
       if( verbosity >= 0 )
@@ -491,13 +492,13 @@ int open_instream( const char * const name, struct stat * const in_statsp,
 
 
 static int open_instream2( const char * const name, struct stat * const in_statsp,
-                           const enum Mode program_mode, const int eindex,
+                           const Mode program_mode, const int eindex,
                            const bool one_to_one, const bool recompress )
   {
   if( program_mode == m_compress && !recompress && eindex >= 0 )
     {
     if( verbosity >= 0 )
-      fprintf( stderr, "%s: %s: Input file already has '%s' suffix.\n",
+      fprintf( stderr, "%s: %s: Input file already has '%s' suffix, ignored.\n",
                program_name, name, known_extensions[eindex].from );
     return -1;
     }
@@ -519,7 +520,7 @@ static bool make_dirs( const char * const name )
     while( i < dirsize && name[i] != '/' ) ++i;
     if( first < i )
       {
-      char partial[i+1]; memcpy( partial, name, i ); partial[i] = 0;
+      char partial[i+1]; memcpy( partial, name, i ); partial[i] = 0; /* vla */
       const mode_t mode = S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH;
       struct stat st;
       if( stat( partial, &st ) == 0 )
@@ -590,7 +591,7 @@ static void signal_handler( int sig )
 
 
 static bool check_tty_in( const char * const input_filename, const int infd,
-                          const enum Mode program_mode, int * const retval )
+                          const Mode program_mode, int * const retval )
   {
   if( ( program_mode == m_decompress || program_mode == m_test ) &&
       isatty( infd ) )				/* for example /dev/tty */
@@ -602,7 +603,7 @@ static bool check_tty_in( const char * const input_filename, const int infd,
   return true;
   }
 
-static bool check_tty_out( const enum Mode program_mode )
+static bool check_tty_out( const Mode program_mode )
   {
   if( program_mode == m_compress && isatty( outfd ) )
     { show_file_error( output_filename[0] ?
@@ -661,30 +662,26 @@ static bool next_filename( void )
   }
 
 
-struct Poly_encoder
-  {
-  struct LZ_encoder_base * eb;
-  struct LZ_encoder * e;
-  struct FLZ_encoder * fe;
-  };
-
-
 static int compress( const unsigned long long cfile_size,
                      const unsigned long long member_size,
                      const unsigned long long volume_size, const int infd,
-                     const struct Lzma_options * const encoder_options,
-                     struct Pretty_print * const pp,
+                     const Lzma_options * const encoder_options,
+                     Pretty_print * const pp,
                      const struct stat * const in_statsp, const bool zero )
   {
-  int retval = 0;
-  struct Poly_encoder encoder = { 0, 0, 0 };	/* polymorphic encoder */
+  struct
+    {
+    LZ_encoder_base * eb;
+    LZ_encoder * e;
+    FLZ_encoder * fe;
+    } encoder = { 0, 0, 0 };			/* polymorphic encoder */
   if( verbosity >= 1 ) Pp_show_msg( pp, 0 );
 
   {
   bool error = false;
   if( zero )
     {
-    encoder.fe = (struct FLZ_encoder *)malloc( sizeof *encoder.fe );
+    encoder.fe = (FLZ_encoder *)malloc( sizeof *encoder.fe );
     if( !encoder.fe || !FLZe_init( encoder.fe, infd, outfd ) ) error = true;
     else encoder.eb = &encoder.fe->eb;
     }
@@ -694,7 +691,7 @@ static int compress( const unsigned long long cfile_size,
     if( Lh_set_dictionary_size( header, encoder_options->dictionary_size ) &&
         encoder_options->match_len_limit >= min_match_len_limit &&
         encoder_options->match_len_limit <= max_match_len )
-      encoder.e = (struct LZ_encoder *)malloc( sizeof *encoder.e );
+      encoder.e = (LZ_encoder *)malloc( sizeof *encoder.e );
     else internal_error( "invalid argument to encoder." );
     if( !encoder.e || !LZe_init( encoder.e, Lh_get_dictionary_size( header ),
                                  encoder_options->match_len_limit, infd, outfd ) )
@@ -709,9 +706,10 @@ static int compress( const unsigned long long cfile_size,
   }
 
   unsigned long long in_size = 0, out_size = 0, partial_volume_size = 0;
+  int retval = 0;
   while( true )			/* encode one member per iteration */
     {
-    const unsigned long long size = ( volume_size > 0 ) ?
+    const unsigned long long size = (volume_size > 0) ?
       min( member_size, volume_size - partial_volume_size ) : member_size;
     show_cprogress( cfile_size, in_size, &encoder.eb->mb, pp );	/* init */
     if( ( zero && !FLZe_encode_member( encoder.fe, size ) ) ||
@@ -765,7 +763,7 @@ static unsigned char xdigit( const unsigned value )	/* hex digit for 'value' */
 
 
 static bool show_trailing_data( const uint8_t * const data, const int size,
-                                struct Pretty_print * const pp, const bool all,
+                                Pretty_print * const pp, const bool all,
                                 const int ignore_trailing )	/* -1 = show */
   {
   if( verbosity >= 4 || ignore_trailing <= 0 )
@@ -793,15 +791,16 @@ static bool show_trailing_data( const uint8_t * const data, const int size,
 
 
 static int decompress( const unsigned long long cfile_size, const int infd,
-                       const struct Cl_options * const cl_opts,
-                       struct Pretty_print * const pp, const bool testing )
+                     const Cl_options * const cl_opts, Pretty_print * const pp,
+                     const bool from_stdin, const bool testing )
   {
   unsigned long long partial_file_pos = 0;
-  struct Range_decoder rdec;
+  Range_decoder rdec;
   int retval = 0;
   bool first_member;
   if( !Rd_init( &rdec, infd ) )
     { show_error( mem_msg, 0, false ); cleanup_and_fail( 1 ); }
+  bool empty = false, multi = false;
 
   for( first_member = true; ; first_member = false )
     {
@@ -841,11 +840,11 @@ static int decompress( const unsigned long long cfile_size, const int infd,
     if( verbosity >= 2 || ( verbosity == 1 && first_member ) )
       Pp_show_msg( pp, 0 );
 
-    struct LZ_decoder decoder;
+    LZ_decoder decoder;
     if( !LZd_init( &decoder, &rdec, dictionary_size, outfd ) )
       { Pp_show_msg( pp, mem_msg ); retval = 1; break; }
     show_dprogress( cfile_size, partial_file_pos, &rdec, pp );	/* init */
-    const int result = LZd_decode_member( &decoder, cl_opts, pp );
+    const int result = LZd_decode_member( &decoder, pp );
     partial_file_pos += Rd_member_position( &rdec );
     LZd_free( &decoder );
     if( result != 0 )
@@ -857,16 +856,19 @@ static int decompress( const unsigned long long cfile_size, const int infd,
                  "File ends unexpectedly" : "Decoder error",
                  partial_file_pos );
         }
-      else if( result == 5 ) Pp_show_msg( pp, empty_msg );
-      else if( result == 6 ) Pp_show_msg( pp, marking_msg );
+      else if( result == 5 ) Pp_show_msg( pp, nonzero_msg );
       retval = 2; break;
       }
+    if( !from_stdin ) { multi = !first_member;
+      if( LZd_data_position( &decoder ) == 0 ) empty = true; }
     if( verbosity >= 2 )
       { fputs( testing ? "ok\n" : "done\n", stderr ); Pp_reset( pp ); }
     }
   Rd_free( &rdec );
   if( verbosity == 1 && retval == 0 )
     fputs( testing ? "ok\n" : "done\n", stderr );
+  if( empty && multi && retval == 0 )
+    { show_file_error( pp->name, empty_msg, 0 ); retval = 2; }
   return retval;
   }
 
@@ -904,13 +906,13 @@ void internal_error( const char * const msg )
 
 void show_cprogress( const unsigned long long cfile_size,
                      const unsigned long long partial_size,
-                     const struct Matchfinder_base * const m,
-                     struct Pretty_print * const p )
+                     const Matchfinder_base * const m,
+                     Pretty_print * const p )
   {
   static unsigned long long csize = 0;		/* file_size / 100 */
   static unsigned long long psize = 0;
-  static const struct Matchfinder_base * mb = 0;
-  static struct Pretty_print * pp = 0;
+  static const Matchfinder_base * mb = 0;
+  static Pretty_print * pp = 0;
   static bool enabled = true;
 
   if( !enabled ) return;
@@ -933,13 +935,13 @@ void show_cprogress( const unsigned long long cfile_size,
 
 void show_dprogress( const unsigned long long cfile_size,
                      const unsigned long long partial_size,
-                     const struct Range_decoder * const d,
-                     struct Pretty_print * const p )
+                     const Range_decoder * const d,
+                     Pretty_print * const p )
   {
   static unsigned long long csize = 0;		/* file_size / 100 */
   static unsigned long long psize = 0;
-  static const struct Range_decoder * rdec = 0;
-  static struct Pretty_print * pp = 0;
+  static const Range_decoder * rdec = 0;
+  static Pretty_print * pp = 0;
   static int counter = 0;
   static bool enabled = true;
 
@@ -966,7 +968,7 @@ int main( const int argc, const char * const argv[] )
   {
   /* Mapping from gzip/bzip2 style 0..9 compression levels to the
      corresponding LZMA compression parameters. */
-  const struct Lzma_options option_mapping[] =
+  const Lzma_options option_mapping[] =
     {
     { 1 << 16,  16 },		/* -0 */
     { 1 << 20,   5 },		/* -1 */
@@ -978,15 +980,14 @@ int main( const int argc, const char * const argv[] )
     { 1 << 24,  68 },		/* -7 */
     { 3 << 23, 132 },		/* -8 */
     { 1 << 25, 273 } };		/* -9 */
-  struct Lzma_options encoder_options = option_mapping[6];  /* default = "-6" */
+  Lzma_options encoder_options = option_mapping[6];	/* default = "-6" */
   const unsigned long long max_member_size = 0x0008000000000000ULL; /* 2 PiB */
   const unsigned long long max_volume_size = 0x4000000000000000ULL; /* 4 EiB */
   unsigned long long member_size = max_member_size;
   unsigned long long volume_size = 0;
   const char * default_output_filename = "";
-  enum Mode program_mode = m_compress;
-  int i;
-  struct Cl_options cl_opts;		/* command-line options */
+  Mode program_mode = m_compress;
+  Cl_options cl_opts;			/* command-line options */
   Cl_options_init( &cl_opts );
   bool force = false;
   bool keep_input_files = false;
@@ -995,46 +996,44 @@ int main( const int argc, const char * const argv[] )
   bool zero = false;
   if( argc > 0 ) invocation_name = argv[0];
 
-  enum { opt_eer = 256, opt_lt, opt_mer };
-  const struct ap_Option options[] =
+  enum { opt_lt = 256 };
+  const ap_Option options[] =
     {
-    { '0', "fast",               ap_no  },
-    { '1', 0,                    ap_no  },
-    { '2', 0,                    ap_no  },
-    { '3', 0,                    ap_no  },
-    { '4', 0,                    ap_no  },
-    { '5', 0,                    ap_no  },
-    { '6', 0,                    ap_no  },
-    { '7', 0,                    ap_no  },
-    { '8', 0,                    ap_no  },
-    { '9', "best",               ap_no  },
-    { 'a', "trailing-error",     ap_no  },
-    { 'b', "member-size",        ap_yes },
-    { 'c', "stdout",             ap_no  },
-    { 'd', "decompress",         ap_no  },
-    { 'f', "force",              ap_no  },
-    { 'F', "recompress",         ap_no  },
-    { 'h', "help",               ap_no  },
-    { 'k', "keep",               ap_no  },
-    { 'l', "list",               ap_no  },
-    { 'm', "match-length",       ap_yes },
-    { 'n', "threads",            ap_yes },
-    { 'o', "output",             ap_yes },
-    { 'q', "quiet",              ap_no  },
-    { 's', "dictionary-size",    ap_yes },
-    { 'S', "volume-size",        ap_yes },
-    { 't', "test",               ap_no  },
-    { 'v', "verbose",            ap_no  },
-    { 'V', "version",            ap_no  },
-    { opt_eer, "empty-error",    ap_no  },
-    { opt_lt,  "loose-trailing", ap_no  },
-    { opt_mer, "marking-error",  ap_no  },
-    {  0, 0,                     ap_no  } };
+    { '0', "fast",              ap_no  },
+    { '1', 0,                   ap_no  },
+    { '2', 0,                   ap_no  },
+    { '3', 0,                   ap_no  },
+    { '4', 0,                   ap_no  },
+    { '5', 0,                   ap_no  },
+    { '6', 0,                   ap_no  },
+    { '7', 0,                   ap_no  },
+    { '8', 0,                   ap_no  },
+    { '9', "best",              ap_no  },
+    { 'a', "trailing-error",    ap_no  },
+    { 'b', "member-size",       ap_yes },
+    { 'c', "stdout",            ap_no  },
+    { 'd', "decompress",        ap_no  },
+    { 'f', "force",             ap_no  },
+    { 'F', "recompress",        ap_no  },
+    { 'h', "help",              ap_no  },
+    { 'k', "keep",              ap_no  },
+    { 'l', "list",              ap_no  },
+    { 'm', "match-length",      ap_yes },
+    { 'n', "threads",           ap_yes },
+    { 'o', "output",            ap_yes },
+    { 'q', "quiet",             ap_no  },
+    { 's', "dictionary-size",   ap_yes },
+    { 'S', "volume-size",       ap_yes },
+    { 't', "test",              ap_no  },
+    { 'v', "verbose",           ap_no  },
+    { 'V', "version",           ap_no  },
+    { opt_lt, "loose-trailing", ap_no  },
+    { 0, 0,                     ap_no  } };
 
   CRC32_init();
 
   /* static because valgrind complains and memory management in C sucks */
-  static struct Arg_parser parser;
+  static Arg_parser parser;
   if( !ap_init( &parser, argc, argv, options, 0 ) )
     { show_error( mem_msg, 0, false ); return 1; }
   if( ap_error( &parser ) )				/* bad option */
@@ -1049,9 +1048,8 @@ int main( const int argc, const char * const argv[] )
     const char * const arg = ap_argument( &parser, argind );
     switch( code )
       {
-      case '0': case '1': case '2': case '3': case '4':
-      case '5': case '6': case '7': case '8': case '9':
-                zero = ( code == '0' );
+      case '0': case '1': case '2': case '3': case '4': case '5':
+      case '6': case '7': case '8': case '9': zero = code == '0';
                 encoder_options = option_mapping[code-'0']; break;
       case 'a': cl_opts.ignore_trailing = false; break;
       case 'b': member_size = getnum( arg, pn, 100000, max_member_size ); break;
@@ -1065,7 +1063,7 @@ int main( const int argc, const char * const argv[] )
       case 'm': encoder_options.match_len_limit =
                   getnum( arg, pn, min_match_len_limit, max_match_len );
                 zero = false; break;
-      case 'n': break;
+      case 'n': break;					/* ignored */
       case 'o': if( strcmp( arg, "-" ) == 0 ) to_stdout = true;
                 else { default_output_filename = arg; } break;
       case 'q': verbosity = -1; break;
@@ -1075,9 +1073,7 @@ int main( const int argc, const char * const argv[] )
       case 't': set_mode( &program_mode, m_test ); break;
       case 'v': if( verbosity < 4 ) ++verbosity; break;
       case 'V': show_version(); return 0;
-      case opt_eer: cl_opts.ignore_empty = false; break;
-      case opt_lt:  cl_opts.loose_trailing = true; break;
-      case opt_mer: cl_opts.ignore_marking = false; break;
+      case opt_lt: cl_opts.loose_trailing = true; break;
       default: internal_error( "uncaught option." );
       }
     } /* end process options */
@@ -1092,6 +1088,7 @@ int main( const int argc, const char * const argv[] )
   filenames = resize_buffer( filenames, num_filenames * sizeof filenames[0] );
   filenames[0] = "-";
 
+  int i;
   bool filenames_given = false;
   for( i = 0; argind + i < ap_arguments( &parser ); ++i )
     {
@@ -1126,7 +1123,7 @@ int main( const int argc, const char * const argv[] )
   if( !to_stdout && program_mode != m_test && ( filenames_given || to_file ) )
     set_signals( signal_handler );
 
-  static struct Pretty_print pp;
+  static Pretty_print pp;
   Pp_init( &pp, filenames, num_filenames );
 
   int failed_tests = 0;
@@ -1138,9 +1135,10 @@ int main( const int argc, const char * const argv[] )
     {
     const char * input_filename = "";
     int infd;
+    const bool from_stdin = strcmp( filenames[i], "-" ) == 0;
 
     Pp_set_name( &pp, filenames[i] );
-    if( strcmp( filenames[i], "-" ) == 0 )
+    if( from_stdin )
       {
       if( stdin_used ) continue; else stdin_used = true;
       infd = STDIN_FILENO;
@@ -1189,7 +1187,8 @@ int main( const int argc, const char * const argv[] )
       tmp = compress( cfile_size, member_size, volume_size, infd,
                       &encoder_options, &pp, in_statsp, zero );
     else
-      tmp = decompress( cfile_size, infd, &cl_opts, &pp, program_mode == m_test );
+      tmp = decompress( cfile_size, infd, &cl_opts, &pp, from_stdin,
+                        program_mode == m_test );
     if( close( infd ) != 0 )
       { show_file_error( pp.name, "Error closing input file", errno );
         set_retval( &tmp, 1 ); }
@@ -1217,6 +1216,7 @@ int main( const int argc, const char * const argv[] )
              program_name, failed_tests,
              ( failed_tests == 1 ) ? "file" : "files" );
   free( output_filename );
+  Pp_free( &pp );
   free( filenames );
   ap_free( &parser );
   return retval;
